using Esri.ArcGISRuntime.Geometry;
using Esri.ArcGISRuntime.Mapping;
using Esri.ArcGISRuntime.UI;
using Esri.ArcGISRuntime.Symbology;
using CommunityToolkit.Mvvm.ComponentModel;
using System.Collections.Generic;

namespace ArcGISApp1
{
    
    public partial class MapViewModel : ObservableObject
    {
        public MapViewModel()
        {
            SetupMap();
            CreateGraphics();

        }

        private void SetupMap()
        {
            Map = new Map(BasemapStyle.OSMStandard);
        }

        private void CreateGraphics()
        {
            var myGraphicsOverlay = new GraphicsOverlay();
            GraphicsOverlayCollection overlays = new GraphicsOverlayCollection
            {
               myGraphicsOverlay
            };
            this.GraphicsOverlays = overlays;

            #region Add Point
            var myPoint = new MapPoint(11.273940726265899, 51.033297177247576, SpatialReferences.Wgs84);

            // Create a symbol to define how the point is displayed.
            var pointSymbol = new SimpleMarkerSymbol
            {
                Style = SimpleMarkerSymbolStyle.Circle,
                Color = System.Drawing.Color.Orange,
                Size = 20.0
            };

            // Add an outline to the symbol.
            pointSymbol.Outline = new SimpleLineSymbol
            {
                Style = SimpleLineSymbolStyle.Solid,
                Color = System.Drawing.Color.Blue,
                Width = 2.0
            };

            // Create a point graphic with the geometry and symbol.
            var pointGraphic = new Graphic(myPoint, pointSymbol);

            // Add the point graphic to graphics overlay.
            myGraphicsOverlay.Graphics.Add(pointGraphic);

            #endregion

            #region Add Line

            List<MapPoint> linePoints = new List<MapPoint>
            {
                new MapPoint(11.273940726265899, 51.033297177247576, SpatialReferences.Wgs84),
                new MapPoint(11.283940726265899, 51.043297177247576, SpatialReferences.Wgs84),
                new MapPoint(11.273940726265899, 51.053297177247576, SpatialReferences.Wgs84)
            };
            var myPolyline = new Polyline(linePoints);
            var polylineSymbol = new SimpleLineSymbol(SimpleLineSymbolStyle.Solid, System.Drawing.Color.Blue, 3.0);

            var polylineGraphic = new Graphic(myPolyline, polylineSymbol);
            myGraphicsOverlay.Graphics.Add(polylineGraphic);
            #endregion

        }


        [ObservableProperty]
        private Map map;

        [ObservableProperty]
        private GraphicsOverlayCollection graphicsOverlays;
      
    }
}
